@@ -1,3 +1,4 @@
+from .. import msg
 from fortpy.testing.templates import FileLine
 from fortpy.docelements import DocElement
 from os import path, remove
@@ -105,8 +106,8 @@ class GlobalDeclaration(object):
         """Returns the fortran declaration that defines a global variable."""
         result = []
         if "type" not in self.attributes or "name" not in self.attributes:
-            print("FATAL: required variable for execution missing some attributes. {}".format(
-                self.attributes))
+            msg.err("required variable for execution missing some attributes." + 
+                    " {}".format(self.attributes))
             exit(1)
 
         result.append(self.attributes["type"])
@@ -887,6 +888,7 @@ class TestTarget(object):
         if position in self.when and self.name[0] != ".":
             if self._code is None:
                 self._process(variables, spacer)
+                
             lines.append(self._code)
 
     def clean(self, testroot):
@@ -931,6 +933,10 @@ class TestTarget(object):
                 #name with a suffix of "_fpy".
                 self._code = "{}call pysave({}_fpy, '{}', {})".format(spacer, self.testspec.executable.name,
                                                                       self.varfile, len(self.varfile))
+            else:
+                raise ValueError("Variable {} has not been initialized with ".format(self.name) +
+                                 "a <global> tag or regular=true parameter doc tag.")
+                
 
     def _parse_attributes(self):
         """Extracts implemented attributes from the test target."""
@@ -1332,8 +1338,8 @@ class TestingGroup(object):
             #to add it again.
             existing = self.variables[name]
             if not existing.compare(doc):
-                print("FATAL: variables in the calling namespace have the same name," + \
-                    " but different types: \n{}{}".format(existing.element, doc))
+                msg.err("variables in the calling namespace have the same name," + \
+                        " but different types: \n{}{}".format(existing.element, doc))
                 exit(1)
 
     def _parse_mappings(self):
